Screenshots — Balladeer 0.39.0

- Introduction
- Basics
  - States
  - Grouping
- Entities
  - Entity objects
  - Entity state
- World
  - WorldBuilder
- Map
  - Compass
  - Traffic and Transits
  - MapBuilder
- Speech
  - Modelling
  - Markup
- Drama
  - `Drama`
  - Interlude
  - Directive handler
  - Dialogue generator
- Story
- Scenes
  - Specifications
  - Shots
  - Conditions
  - Model
- Themes
  - CSS
  - Class
  - Theming
- Styles
- Web
- Screenshots
  - Traditional
  - Artistic
  - Technical
- Change Log
  - 0.39.0
  - 0.38.0
  - 0.37.0
  - 0.36.0
  - 0.35.0
  - 0.34.0
  - 0.33.0
  - 0.32.0
  - 0.31.0
  - 0.30.0
  - 0.29.0
  - 0.28.0
  - 0.27.0
  - 0.26.0
  - 0.25.0
  - 0.24.0
  - 0.23.0
  - 0.22.0
  - 0.21.0
  - 0.20.0
  - 0.19.0
  - 0.18.0
  - 0.17.0
  - 0.16.0
  - 0.15.0
  - 0.14.0
  - 0.13.0
  - 0.12.0
  - 0.11.0
  - 0.10.0
  - 0.9.0
  - 0.8.0
  - 0.7.0

# Screenshots

## Traditional

A recreation of the famous Cloak of Darkness Interactive Fiction.

## Artistic

Application of CSS styling and layout.

## Technical

Example of SVG icons and a Javascript product viewer.